﻿using Android.App;
using Android.OS;
using Android.Views;
using Android.Widget;
using ThinkGeo.MapSuite.AndroidEdition;
using ThinkGeo.MapSuite.Core;

namespace DetectingZoomPanSample
{
    [Activity(Label = "DetectingZoomPanSample", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        private MapView mapView;
        private bool isScaleChanged;
        private bool isExtentChanged;

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);
            SetContentView(Resource.Layout.Main);

            mapView = FindViewById<MapView>(Resource.Id.MapView);
            mapView.MapUnit = GeographyUnit.DecimalDegree;
            mapView.CurrentExtent = new RectangleShape(-180, 90, 180, -90);

            WorldMapKitOverlay worldMapKitOverlay = new WorldMapKitOverlay();
            mapView.Overlays.Add(worldMapKitOverlay);

            mapView.Touch += MapViewTouch;
            mapView.CurrentExtentChanged += MapViewCurrentExtentChanged;
            mapView.CurrentScaleChanged += MapViewCurrentScaleChanged;
        }

        void MapViewCurrentScaleChanged(object sender, CurrentScaleChangedMapViewEventArgs e)
        {
            isScaleChanged = true;
        }

        void MapViewCurrentExtentChanged(object sender, CurrentExtentChangedMapViewEventArgs e)
        {
            if (e.OldExtent.ToString() != e.NewExtent.ToString()) isExtentChanged = true;
        }

        void MapViewTouch(object sender, View.TouchEventArgs e)
        {
            if (isScaleChanged && isExtentChanged && e.Event.PointerCount == 2)
            {
                Toast.MakeText(this, "MapView_Zoom", ToastLength.Short).Show();
            }

            if (!isScaleChanged && isExtentChanged && e.Event.PointerCount == 1)
            {
                Toast.MakeText(this, "MapView_Pan", ToastLength.Short).Show();
            }

            isScaleChanged = false;
            isExtentChanged = false;
        }
    }
}

